from setuptools import setup
from distutils.core import setup
from os import path

setup(
  name = 'asx',
  packages = ['asx'],
  version = '1.5.0',
  license='MIT',
  description = 'Python library to access the ASX API: https://www.asx.com.au/asx/1/share',
  long_description="""ASX is a package to pull data from https://www.asx.com.au/asx/1/share.

## Requirements
- Install Python 3.9 (for all users)
- Pip install requests

## Usage

Connect to ASX API:

    import asx
    ASX = asx.api()
    ASX.getdata(Symbol)
""",
  long_description_content_type='text/markdown',
  author = 'Leigh Curran',
  author_email = 'ASXPy@outlook.com',
  url = 'https://github.com/leighcurran/ASX',
  keywords = ['ASX', 'API'],
  install_requires=[
          'requests',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)


"""Abstraction of the ASX API"""
import requests
from requests.adapters import HTTPAdapter
from requests.exceptions import Timeout

class api:

    def __init__(self):
        self.Error = None
        self.token = None
        self.url = 'https://www.asx.com.au/asx/1/share/'  
        api_adapter = HTTPAdapter(max_retries=2)
        
        """Create a session and perform all requests in the same session"""
        session = requests.Session()
        session.mount(self.url, api_adapter)
        session.headers.update({'Accept': 'application/json', 'User-Agent': 'ASX.py', 'Accept-Encoding' : 'gzip, deflate, br', 'Connection' : 'keep-alive' })
        self.session = session

    def request(self, Symbol): 
        try:
            request = self.session.get(self.url + Symbol)
            if (request.status_code == 200):
                return request.json()
            else:
                self.Error = 'Data request failed: ' + request.reason  
        except Timeout:
            self.Error = 'Data request timed out'

    def getdata(self, Symbol):
        data = self.request(Symbol)
        self.last_price = data['last_price']
        self.open_price = data['open_price']
        self.day_high_price = data['day_high_price']
        self.day_low_price = data['day_low_price']
        self.change_price = data['change_price']
        self.change_in_percent = data['change_in_percent']
        self.bid_price = data['bid_price']
        self.offer_price = data['offer_price']
        self.previous_close_price = data['previous_close_price']
        self.previous_day_percentage_change = data['previous_day_percentage_change']
        self.year_high_price = data['year_high_price']
        self.year_low_price = data["year_low_price"]
        self.year_open_price = data["year_open_price"]
        self.year_change_price = data["year_change_price"]
        self.annual_dividend_yield = data["annual_dividend_yield"]